==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_fields/FIELDATTRIBUTE_TYPE.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour FIELDATTRIBUTE_TYPE complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="FIELDATTRIBUTE_TYPE">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="FIELDATTRIBUTECODE" type="{http://schemas.datastream.net/MP_fields}CODE1_Type"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "FIELDATTRIBUTE_TYPE", propOrder = {
    "fieldattributecode",
    "description"
})
public class FIELDATTRIBUTE_TYPE {

    @XmlElement(name = "FIELDATTRIBUTECODE", required = true)
    protected String fieldattributecode;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Obtient la valeur de la propriété fieldattributecode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFIELDATTRIBUTECODE() {
        return fieldattributecode;
    }

    /**
     * Définit la valeur de la propriété fieldattributecode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFIELDATTRIBUTECODE(String value) {
        this.fieldattributecode = value;
    }

    /**
     * Obtient la valeur de la propriété description.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Définit la valeur de la propriété description.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}

==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_fields/FIELDATTRIBUTE_TYPE.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for FIELDATTRIBUTE_TYPE complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="FIELDATTRIBUTE_TYPE">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="FIELDATTRIBUTECODE" type="{http://schemas.datastream.net/MP_fields}CODE1_Type"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "FIELDATTRIBUTE_TYPE", propOrder = {
    "fieldattributecode",
    "description"
})
public class FIELDATTRIBUTE_TYPE {

    @XmlElement(name = "FIELDATTRIBUTECODE", required = true)
    protected String fieldattributecode;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Gets the value of the fieldattributecode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFIELDATTRIBUTECODE() {
        return fieldattributecode;
    }

    /**
     * Sets the value of the fieldattributecode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFIELDATTRIBUTECODE(String value) {
        this.fieldattributecode = value;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}
